==> open-cluster-management-apps-model-6.1.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/SubscriptionStatusFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SubscriptionStatusFluentImpl<A extends SubscriptionStatusFluent<A>> extends BaseFluent<A> implements SubscriptionStatusFluent<A>{
  public SubscriptionStatusFluentImpl() {
  }
  public SubscriptionStatusFluentImpl(SubscriptionStatus instance) {
    this.withAnsiblejobs(instance.getAnsiblejobs()); 
    this.withLastUpdateTime(instance.getLastUpdateTime()); 
    this.withMessage(instance.getMessage()); 
    this.withPhase(instance.getPhase()); 
    this.withReason(instance.getReason()); 
    this.withStatuses(instance.getStatuses()); 
  }
  private AnsibleJobsStatusBuilder ansiblejobs;
  private String lastUpdateTime;
  private String message;
  private String phase;
  private String reason;
  private Map<String,SubscriptionPerClusterStatus> statuses;
  
  /**
   * This method has been deprecated, please use method buildAnsiblejobs instead.
   * @return The buildable object.
   */
  @Deprecated
  public AnsibleJobsStatus getAnsiblejobs() {
    return this.ansiblejobs!=null ?this.ansiblejobs.build():null;
  }
  public AnsibleJobsStatus buildAnsiblejobs() {
    return this.ansiblejobs!=null ?this.ansiblejobs.build():null;
  }
  public A withAnsiblejobs(AnsibleJobsStatus ansiblejobs) {
    _visitables.get("ansiblejobs").remove(this.ansiblejobs);
    if (ansiblejobs!=null){ this.ansiblejobs= new AnsibleJobsStatusBuilder(ansiblejobs); _visitables.get("ansiblejobs").add(this.ansiblejobs);} else { this.ansiblejobs = null; _visitables.get("ansiblejobs").remove(this.ansiblejobs); } return (A) this;
  }
  public Boolean hasAnsiblejobs() {
    return this.ansiblejobs != null;
  }
  public SubscriptionStatusFluent.AnsiblejobsNested<A> withNewAnsiblejobs() {
    return new SubscriptionStatusFluentImpl.AnsiblejobsNestedImpl();
  }
  public SubscriptionStatusFluent.AnsiblejobsNested<A> withNewAnsiblejobsLike(AnsibleJobsStatus item) {
    return new SubscriptionStatusFluentImpl.AnsiblejobsNestedImpl(item);
  }
  public SubscriptionStatusFluent.AnsiblejobsNested<A> editAnsiblejobs() {
    return withNewAnsiblejobsLike(getAnsiblejobs());
  }
  public SubscriptionStatusFluent.AnsiblejobsNested<A> editOrNewAnsiblejobs() {
    return withNewAnsiblejobsLike(getAnsiblejobs() != null ? getAnsiblejobs(): new AnsibleJobsStatusBuilder().build());
  }
  public SubscriptionStatusFluent.AnsiblejobsNested<A> editOrNewAnsiblejobsLike(AnsibleJobsStatus item) {
    return withNewAnsiblejobsLike(getAnsiblejobs() != null ? getAnsiblejobs(): item);
  }
  public String getLastUpdateTime() {
    return this.lastUpdateTime;
  }
  public A withLastUpdateTime(String lastUpdateTime) {
    this.lastUpdateTime=lastUpdateTime; return (A) this;
  }
  public Boolean hasLastUpdateTime() {
    return this.lastUpdateTime != null;
  }
  public String getMessage() {
    return this.message;
  }
  public A withMessage(String message) {
    this.message=message; return (A) this;
  }
  public Boolean hasMessage() {
    return this.message != null;
  }
  public String getPhase() {
    return this.phase;
  }
  public A withPhase(String phase) {
    this.phase=phase; return (A) this;
  }
  public Boolean hasPhase() {
    return this.phase != null;
  }
  public String getReason() {
    return this.reason;
  }
  public A withReason(String reason) {
    this.reason=reason; return (A) this;
  }
  public Boolean hasReason() {
    return this.reason != null;
  }
  public A addToStatuses(String key,SubscriptionPerClusterStatus value) {
    if(this.statuses == null && key != null && value != null) { this.statuses = new LinkedHashMap(); }
    if(key != null && value != null) {this.statuses.put(key, value);} return (A)this;
  }
  public A addToStatuses(Map<String,SubscriptionPerClusterStatus> map) {
    if(this.statuses == null && map != null) { this.statuses = new LinkedHashMap(); }
    if(map != null) { this.statuses.putAll(map);} return (A)this;
  }
  public A removeFromStatuses(String key) {
    if(this.statuses == null) { return (A) this; }
    if(key != null && this.statuses != null) {this.statuses.remove(key);} return (A)this;
  }
  public A removeFromStatuses(Map<String,SubscriptionPerClusterStatus> map) {
    if(this.statuses == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.statuses != null){this.statuses.remove(key);}}} return (A)this;
  }
  public Map<String,SubscriptionPerClusterStatus> getStatuses() {
    return this.statuses;
  }
  public <K,V>A withStatuses(Map<String,SubscriptionPerClusterStatus> statuses) {
    if (statuses == null) { this.statuses =  null;} else {this.statuses = new LinkedHashMap(statuses);} return (A) this;
  }
  public Boolean hasStatuses() {
    return this.statuses != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SubscriptionStatusFluentImpl that = (SubscriptionStatusFluentImpl) o;
    if (ansiblejobs != null ? !ansiblejobs.equals(that.ansiblejobs) :that.ansiblejobs != null) return false;
    if (lastUpdateTime != null ? !lastUpdateTime.equals(that.lastUpdateTime) :that.lastUpdateTime != null) return false;
    if (message != null ? !message.equals(that.message) :that.message != null) return false;
    if (phase != null ? !phase.equals(that.phase) :that.phase != null) return false;
    if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
    if (statuses != null ? !statuses.equals(that.statuses) :that.statuses != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ansiblejobs,  lastUpdateTime,  message,  phase,  reason,  statuses,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ansiblejobs != null) { sb.append("ansiblejobs:"); sb.append(ansiblejobs + ","); }
    if (lastUpdateTime != null) { sb.append("lastUpdateTime:"); sb.append(lastUpdateTime + ","); }
    if (message != null) { sb.append("message:"); sb.append(message + ","); }
    if (phase != null) { sb.append("phase:"); sb.append(phase + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason + ","); }
    if (statuses != null && !statuses.isEmpty()) { sb.append("statuses:"); sb.append(statuses); }
    sb.append("}");
    return sb.toString();
  }
  class AnsiblejobsNestedImpl<N> extends AnsibleJobsStatusFluentImpl<SubscriptionStatusFluent.AnsiblejobsNested<N>> implements SubscriptionStatusFluent.AnsiblejobsNested<N>,Nested<N>{
    AnsiblejobsNestedImpl(AnsibleJobsStatus item) {
      this.builder = new AnsibleJobsStatusBuilder(this, item);
    }
    AnsiblejobsNestedImpl() {
      this.builder = new AnsibleJobsStatusBuilder(this);
    }
    AnsibleJobsStatusBuilder builder;
    public N and() {
      return (N) SubscriptionStatusFluentImpl.this.withAnsiblejobs(builder.build());
    }
    public N endAnsiblejobs() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-apps-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/SubscriptionStatusFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SubscriptionStatusFluentImpl<A extends SubscriptionStatusFluent<A>> extends BaseFluent<A> implements SubscriptionStatusFluent<A>{
  public SubscriptionStatusFluentImpl() {
  }
  public SubscriptionStatusFluentImpl(SubscriptionStatus instance) {
    if (instance != null) {
      this.withAnsiblejobs(instance.getAnsiblejobs());
      this.withLastUpdateTime(instance.getLastUpdateTime());
      this.withMessage(instance.getMessage());
      this.withPhase(instance.getPhase());
      this.withReason(instance.getReason());
      this.withStatuses(instance.getStatuses());
    }
  }
  private AnsibleJobsStatusBuilder ansiblejobs;
  private String lastUpdateTime;
  private String message;
  private String phase;
  private String reason;
  private Map<String,SubscriptionPerClusterStatus> statuses;
  
  /**
   * This method has been deprecated, please use method buildAnsiblejobs instead.
   * @return The buildable object.
   */
  @Deprecated
  public AnsibleJobsStatus getAnsiblejobs() {
    return this.ansiblejobs!=null ?this.ansiblejobs.build():null;
  }
  public AnsibleJobsStatus buildAnsiblejobs() {
    return this.ansiblejobs!=null ?this.ansiblejobs.build():null;
  }
  public A withAnsiblejobs(AnsibleJobsStatus ansiblejobs) {
    _visitables.get("ansiblejobs").remove(this.ansiblejobs);
    if (ansiblejobs!=null){ this.ansiblejobs= new AnsibleJobsStatusBuilder(ansiblejobs); _visitables.get("ansiblejobs").add(this.ansiblejobs);} else { this.ansiblejobs = null; _visitables.get("ansiblejobs").remove(this.ansiblejobs); } return (A) this;
  }
  public Boolean hasAnsiblejobs() {
    return this.ansiblejobs != null;
  }
  public SubscriptionStatusFluentImpl.AnsiblejobsNested<A> withNewAnsiblejobs() {
    return new SubscriptionStatusFluentImpl.AnsiblejobsNestedImpl();
  }
  public SubscriptionStatusFluentImpl.AnsiblejobsNested<A> withNewAnsiblejobsLike(AnsibleJobsStatus item) {
    return new SubscriptionStatusFluentImpl.AnsiblejobsNestedImpl(item);
  }
  public SubscriptionStatusFluentImpl.AnsiblejobsNested<A> editAnsiblejobs() {
    return withNewAnsiblejobsLike(getAnsiblejobs());
  }
  public SubscriptionStatusFluentImpl.AnsiblejobsNested<A> editOrNewAnsiblejobs() {
    return withNewAnsiblejobsLike(getAnsiblejobs() != null ? getAnsiblejobs(): new AnsibleJobsStatusBuilder().build());
  }
  public SubscriptionStatusFluentImpl.AnsiblejobsNested<A> editOrNewAnsiblejobsLike(AnsibleJobsStatus item) {
    return withNewAnsiblejobsLike(getAnsiblejobs() != null ? getAnsiblejobs(): item);
  }
  public String getLastUpdateTime() {
    return this.lastUpdateTime;
  }
  public A withLastUpdateTime(String lastUpdateTime) {
    this.lastUpdateTime=lastUpdateTime; return (A) this;
  }
  public Boolean hasLastUpdateTime() {
    return this.lastUpdateTime != null;
  }
  public String getMessage() {
    return this.message;
  }
  public A withMessage(String message) {
    this.message=message; return (A) this;
  }
  public Boolean hasMessage() {
    return this.message != null;
  }
  public String getPhase() {
    return this.phase;
  }
  public A withPhase(String phase) {
    this.phase=phase; return (A) this;
  }
  public Boolean hasPhase() {
    return this.phase != null;
  }
  public String getReason() {
    return this.reason;
  }
  public A withReason(String reason) {
    this.reason=reason; return (A) this;
  }
  public Boolean hasReason() {
    return this.reason != null;
  }
  public A addToStatuses(String key,SubscriptionPerClusterStatus value) {
    if(this.statuses == null && key != null && value != null) { this.statuses = new LinkedHashMap(); }
    if(key != null && value != null) {this.statuses.put(key, value);} return (A)this;
  }
  public A addToStatuses(Map<String,SubscriptionPerClusterStatus> map) {
    if(this.statuses == null && map != null) { this.statuses = new LinkedHashMap(); }
    if(map != null) { this.statuses.putAll(map);} return (A)this;
  }
  public A removeFromStatuses(String key) {
    if(this.statuses == null) { return (A) this; }
    if(key != null && this.statuses != null) {this.statuses.remove(key);} return (A)this;
  }
  public A removeFromStatuses(Map<String,SubscriptionPerClusterStatus> map) {
    if(this.statuses == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.statuses != null){this.statuses.remove(key);}}} return (A)this;
  }
  public Map<String,SubscriptionPerClusterStatus> getStatuses() {
    return this.statuses;
  }
  public <K,V>A withStatuses(Map<String,SubscriptionPerClusterStatus> statuses) {
    if (statuses == null) { this.statuses =  null;} else {this.statuses = new LinkedHashMap(statuses);} return (A) this;
  }
  public Boolean hasStatuses() {
    return this.statuses != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubscriptionStatusFluentImpl that = (SubscriptionStatusFluentImpl) o;
    if (!java.util.Objects.equals(ansiblejobs, that.ansiblejobs)) return false;

    if (!java.util.Objects.equals(lastUpdateTime, that.lastUpdateTime)) return false;

    if (!java.util.Objects.equals(message, that.message)) return false;

    if (!java.util.Objects.equals(phase, that.phase)) return false;

    if (!java.util.Objects.equals(reason, that.reason)) return false;

    if (!java.util.Objects.equals(statuses, that.statuses)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ansiblejobs,  lastUpdateTime,  message,  phase,  reason,  statuses,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ansiblejobs != null) { sb.append("ansiblejobs:"); sb.append(ansiblejobs + ","); }
    if (lastUpdateTime != null) { sb.append("lastUpdateTime:"); sb.append(lastUpdateTime + ","); }
    if (message != null) { sb.append("message:"); sb.append(message + ","); }
    if (phase != null) { sb.append("phase:"); sb.append(phase + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason + ","); }
    if (statuses != null && !statuses.isEmpty()) { sb.append("statuses:"); sb.append(statuses); }
    sb.append("}");
    return sb.toString();
  }
  class AnsiblejobsNestedImpl<N> extends AnsibleJobsStatusFluentImpl<SubscriptionStatusFluentImpl.AnsiblejobsNested<N>> implements SubscriptionStatusFluentImpl.AnsiblejobsNested<N>,Nested<N>{
    AnsiblejobsNestedImpl(AnsibleJobsStatus item) {
      this.builder = new AnsibleJobsStatusBuilder(this, item);
    }
    AnsiblejobsNestedImpl() {
      this.builder = new AnsibleJobsStatusBuilder(this);
    }
    AnsibleJobsStatusBuilder builder;
    public N and() {
      return (N) SubscriptionStatusFluentImpl.this.withAnsiblejobs(builder.build());
    }
    public N endAnsiblejobs() {
      return and();
    }
    
  }
  
}
